;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "sdml-mode" "20251024.1329"
  "Major mode for SDML."
  '((emacs              "28.1")
    (tree-sitter        "0.18.0")
    (tree-sitter-indent "0.4"))
  :url "https://github.com/sdm-lang/emacs-sdml-mode"
  :commit "4371a66f134b22493efeb4f3a0af8e7d180c66fb"
  :revdesc "4371a66f134b"
  :keywords '("languages" "tools")
  :authors '(("Simon Johnston" . "johnstonskj@gmail.com"))
  :maintainers '(("Simon Johnston" . "johnstonskj@gmail.com")))
